#!/usr/local/bin/python
# -*- coding:utf-8 -*-
"""
    2016/8/26  WeiYanfeng
    添加了线程缓存功能的管道服务端。
"""
# import _addpath
from . import _addpath
import sys

from weberFuncs import PrintTimeMsg
from weberFuncs import CThreadCacheByQueue
from pipe.TCmdPipeServer import TCmdPipeServer


class TCmdPipeServerTCBQ(TCmdPipeServer):
    def __init__(self, iServerPort, sServerIP, ftCallBackForPush):
        self.ftCallBackForPush = ftCallBackForPush
        self.tcbq = CThreadCacheByQueue(self.ftCallBackForPush)
        TCmdPipeServer.__init__(self, iServerPort, sServerIP)

    def HandlePipeError(self, sRet, sMsg):
        PrintTimeMsg('TCmdPipeServerTCBQ.HandlePipeError(%s,%s)EXIT!' % (sRet, sMsg))
        self.SetLoopRunFlagToQuit('HandlePipeError=(%s.%s)' % (sRet, sMsg))
        sys.exit(-1)

    def HandlePipeRequest(self, CmdStr):
        self.tcbq.PutToQueue(CmdStr)



#!/usr/local/bin/python
# -*- coding:utf-8 -*-
"""
    2016/9/2  WeiYanfeng
    请简要说明当前程序的功能
"""
import sys
from .CGlobalExitFlag import CGlobalExitFlag

import signal
gef = CGlobalExitFlag()


def SetGlobalFlagToQuit(errno):
    global gef
    gef.SetExitFlagTrue("SetGlobalFlagToQuit.errno=%d" % errno)
    sys.exit(errno)


def sig_handler(signum, frame):
    global gef
    gef.SetExitFlagTrue("receive a signal %d" % signum)

signal.signal(signal.SIGINT, sig_handler)
signal.signal(signal.SIGTERM, sig_handler)
# ------------------------------------------------


class CssException(Exception):
    def __init__(self, errno, errmsg):
        global gef
        self.errno = errno
        self.errmsg = errmsg
        gef.SetExitFlagTrue('CssException')

    def __str__(self):
        return 'CssException.errno=%s,errmsg=%s' % (
            repr(self.errno), repr(self.errmsg) )


#!/usr/local/bin/python
# -*- coding:utf-8 -*-
"""
    2018/3/6  WeiYanfeng
    启动服务相关函数。

"""

# import _addpath
# import sys
import time
from weberFuncs import PrintTimeMsg, LoopPrintSleep, PrettyPrintStr
import importlib


def TryToImportSettingsVariable(sSettingsModule, sVariableName):
    # 动态加载 PipePeerServer 参数配置
    # from ppsSettings import gDictPipePeerServerParam
    PrintTimeMsg('TryToImportSettingsVariable.import_module(%s)...' % sSettingsModule)
    try:
        p = importlib.import_module(sSettingsModule)
        # print(dir(p))
        # dictP = getattr(p, 'gDictPipePeerServerParam')  # p.gDictPipePeerServerParam
        dictP = getattr(p, sVariableName)
        PrintTimeMsg('Var(%s)=(%s)' % (sVariableName, PrettyPrintStr(dictP)))
        return p.gDictPipePeerServerParam
    except ImportError as e:
        PrintTimeMsg('TryToImportSettingsVariable.import_module(%s).e=%s!' % (sSettingsModule, str(e)))
    return None


def TimeRunPipePeerServer(cbServerFunc, *args, **kwargs):
    tmBegin = time.time()
    cbServerFunc(*args, **kwargs)
    if time.time() - tmBegin < 10:
        LoopPrintSleep(60, 10, 'TimeRunPipePeerServer.ErrorQuit')
    PrintTimeMsg('TimeRunPipePeerServer.End!')

